==> xfonts-utils_7.4+1.tar.gz: xfonts-utils/mkfontscale/hash.h <==
/*
  Copyright (c) 2003 by Juliusz Chroboczek

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
*/
/* $XFree86$ */

#ifndef _MKS_HASH_H_
#define _MKS_HASH_H_ 1

typedef struct _HashBucket {
    char *key;
    char *value;
    int prio;
    struct _HashBucket *next;
} HashBucketRec, *HashBucketPtr;

typedef HashBucketPtr* HashTablePtr;

HashTablePtr makeHashTable(void);
void destroyHashTable(HashTablePtr table);
char *getHash(HashTablePtr table, char *key);
int putHash(HashTablePtr table, char *key, char *value, int prio);
int hashElements(HashTablePtr table);
HashBucketPtr *hashArray(HashTablePtr table, int value_first);
void destroyHashArray(HashBucketPtr *array);

#endif /* _MKS_HASH_H */

==> xfonts-utils_7.7+6.tar.gz: xfonts-utils/mkfontscale/hash.h <==
/*
  Copyright (c) 2003 by Juliusz Chroboczek

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
*/

#ifndef _MKS_HASH_H_
#define _MKS_HASH_H_ 1

typedef struct _HashBucket {
    char *key;
    char *value;
    int prio;
    struct _HashBucket *next;
} HashBucketRec, *HashBucketPtr;

typedef HashBucketPtr* HashTablePtr;

HashTablePtr makeHashTable(void);
void destroyHashTable(HashTablePtr table);
char *getHash(HashTablePtr table, const char *key);
int putHash(HashTablePtr table, char *key, char *value, int prio);
int hashElements(HashTablePtr table);
HashBucketPtr *hashArray(HashTablePtr table, int value_first);
void destroyHashArray(HashBucketPtr *array);

#endif /* _MKS_HASH_H */
